pub enum StateSpaceError {
DimensionMismatch {
expected: usize,
found: usize,
},
InvalidBound {
lower: f64,
upper: f64,
},
ZeroDimensionUnbounded,
InvalidAngularDistance {
lower: f64,
},
}Variants
DimensionMismatch
The length of the provided bounds does not match the dimension.
InvalidBound
A lower bound is greater than or equal to its corresponding upper bound.
ZeroDimensionUnbounded
A 0-dimensional space was requested without explicit (empty) bounds.
InvalidAngularDistance
Below the least angular bound